//
//  ViewController.m
//  SelectDemo
//
//  Created by weimengyu on 16/6/1.
//  Copyright © 2016年 weimengyu. All rights reserved.
//

#import "ViewController.h"
#import "TableViewCustomCell.h"
#define ScreenHeight CGRectGetHeight([UIScreen mainScreen].bounds)
#define ScreenWidth CGRectGetWidth([UIScreen mainScreen].bounds)
@interface ViewController ()<UITableViewDelegate,UITableViewDataSource>
@property (nonatomic ,retain)UITableView*MyTableView;
//建立一个可变字典,记录选择的内容.
@property (nonatomic, retain)NSMutableDictionary *selectedSourceDic;
@end

@implementation ViewController
//利用懒加载模式加载tableview.
- (UITableView *)MyTableView {
    if (!_MyTableView) {
        _MyTableView = [[UITableView alloc]init];
        //_MyTableView.backgroundColor = [UIColor redColor];
        _MyTableView.frame = CGRectMake(0, 0, ScreenWidth, ScreenHeight);
        
        [_MyTableView registerNib:[UINib nibWithNibName:@"TableViewCustomCell" bundle:nil] forCellReuseIdentifier:@"TableViewCustomCell"];
        
        _MyTableView.delegate = self;
        _MyTableView.dataSource = self;
        
    }
    return _MyTableView;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    self.automaticallyAdjustsScrollViewInsets = NO;
    self.selectedSourceDic = [[NSMutableDictionary alloc]init];
    [self.view addSubview:self.MyTableView];
    // Do any additional setup after loading the view, typically from a nib.
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return 10;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    //注册单元格(我用的是xib来自定义单元格,如果不允许用Xib,可以代码自定义)
    TableViewCustomCell *cell = [tableView dequeueReusableCellWithIdentifier:@"TableViewCustomCell" forIndexPath:indexPath];
    //将序号作为每一行的标题.
    cell.myTitleLabel.text=[NSString stringWithFormat:@"%ld",(long)indexPath.row+1];
    //在cell里面添加按钮的点击事件;
    [cell.firstChoose addTarget:self action:@selector(onBtnClick:) forControlEvents:UIControlEventTouchUpInside];
    [cell.secondChoose addTarget:self action:@selector(onBtnClick:) forControlEvents:UIControlEventTouchUpInside];
    //设置tag值区分点击的是哪个按钮
    cell.firstChoose.tag=1;
    cell.secondChoose.tag=2;
    //设置按钮的图片样式,也可以改变颜色.
    [cell.firstChoose setImage:[UIImage imageNamed:@"practise_a_n_day"] forState:UIControlStateNormal];
    [cell.secondChoose setImage:[UIImage imageNamed:@"practise_b_n_day"] forState:UIControlStateNormal];
    //将点击cell产生的灰色效果去掉,否则会影响整体美观.
    cell.selectionStyle=UITableViewCellSelectionStyleNone;
    /*根据key值indexPath获取字典中存储的答案,主要的功能就是防止滑动时候内容的掩盖问题*/
    NSString *selectResult = [self.selectedSourceDic objectForKey:indexPath];
    if (selectResult) {
        //如果这个答案存在,说明这个按钮被选择过
        if([selectResult isEqualToString:@"A"]) {
            //选择的是A按钮,A按钮颜色变成灰色
            [cell.firstChoose setImage:[UIImage imageNamed:@"practise_a_s_day"] forState:UIControlStateNormal];
        } else {
            //选择的是B按钮,B按钮颜色变成灰色
            [cell.secondChoose setImage:[UIImage imageNamed:@"practise_b_s_day"] forState:UIControlStateNormal];
        }
    }


    return cell;
}
-(void)onBtnClick:(UIButton *)sender{
     TableViewCustomCell*cell=(TableViewCustomCell *)sender.superview.superview;
    NSIndexPath *indexPath=[self.MyTableView indexPathForCell:cell];
    NSString *lastSelectResult = [self.selectedSourceDic objectForKey:indexPath];
    //如果lastSelectResult的值存在,说明这个cell上以及有按钮被选过了
    if ([lastSelectResult isEqualToString:@"A"]) {
        //改变原有选过的按钮颜色变成初始色
        UIButton *lastSelectBtnA = [cell viewWithTag:1];
        [lastSelectBtnA setImage:[UIImage imageNamed:@"practise_a_n_day"] forState:UIControlStateNormal];
    } else {
        //改变原有选过的按钮颜色变成初始色
        UIButton *lastSelectBtnB = [cell viewWithTag:2];
        [lastSelectBtnB setImage:[UIImage imageNamed:@"practise_b_n_day"] forState:UIControlStateNormal];
    }
    //并且需要移除这个曾经存在过的元素
    [self.selectedSourceDic removeObjectForKey:indexPath];
    
    
    
    
    /*******************这个部分就是为了添加刚刚选中的按钮答案,以及修改他得背景颜色***************/
    
    
    //这个就是添加新选中的按钮答案到字典,根据indexPath作为key,并改变选中时的背景图片
    if (sender.tag == 1) {
        [self.selectedSourceDic setObject:@"A" forKey:indexPath];
        [sender setImage:[UIImage imageNamed:@"practise_a_s_day"] forState:UIControlStateNormal];
    } else {
        [self.selectedSourceDic setObject:@"B" forKey:indexPath];
        [sender setImage:[UIImage imageNamed:@"practise_b_s_day"] forState:UIControlStateNormal];
    }
    NSLog(@"%@",self.selectedSourceDic);
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath{
    //这里行高被我设定为固定值,如果需要动态设置推荐一个第三方库:UITableView+FDTemplateLayoutCell,
    return 93;
}
@end
